using JuMP
using Gurobi

Q = readdlm("cov48.txt")
Q = Q[2:49,2:49]
Q = convert(Array{Float64,2},Q)

R = readdlm("ret48.txt")
R = R[:,2]
N = size(R,1)

minrisk = Model(solver=GurobiSolver(OutputFlag=0))
maxretr = Model(solver=GurobiSolver(OutputFlag=0))

@defVar(minrisk, 0 <= xq[1:N] <= 1 )
@defVar(maxretr, 0 <= xr[1:N] <= 1 )

# agg. il vincolo x'R >= beta

beta = 0.0
@addConstraint(minrisk, (xq'*ones(N))[1] == 1.0)
@addConstraint(maxretr, (xr'*ones(N))[1] == 1.0)

@addConstraint(minrisk,(xq'*R)[1] >= beta)
@setObjective(minrisk, Min, (xq'*Q*xq)[1])

@addConstraint(maxretr, (xr'*Q*xr)[1] <= Inf)
@setObjective(maxretr, Max, (xr'*R)[1])



solve(minrisk)
xq = getValue(xq)

solve(maxretr)
xr = getValue(xr)

beta1 = (xq'*R)[1]
beta2 = (xr'*R)[1]
delta = 0.0001
fid = open("mark.out","w")

for beta = collect(beta1:delta:beta2)
	m = Model(solver=GurobiSolver())

	@defVar(m, 0 <= x[1:N] <= 1 )

	@addConstraint(m, (x'*ones(N))[1] == 1.0)
	@addConstraint(m,(x'*R)[1] >= beta)
	@setObjective(m, Min, (x'*Q*x)[1])

	solve(m)
	x = getValue(x)
	risk = (x'*Q*x)[1]
	
	@printf(fid,"%lf %lf\n",beta,risk)
end
close(fid)

nothing

