using NLopt

println("NLopt version: ",NLOPT_VERSION)

###########################################################
# Problema di Markowitz
###########################################################

Q = readdlm("cov48.txt")
Q = Q[2:49,2:49]
Q = convert(Array{Float64,2},Q)

R = readdlm("ret48.txt")
R = R[:,2]
n = size(R,1)

function quad!(x::Vector, g::Vector)
    n  = length(x)
	h  = Q*x
    f  = (x'*h)[1]

    if length(g) > 0
		for i = 1:n
			g[i] = h[i] 
		end
    end
    return f
end

beta = 0.0

function rend!(x::Vector, g::Vector)
    n = length(x)
	f = (x'*R)[1] - beta
	if length(g) > 0
		for i = 1:n
			g[i] = -R[i]
		end
	end

	return -f
end

function simpl!(x::Vector, g::Vector)
    n = length(x)
	f = 0.0
	for i = 1:n
		f += x[i]
	end
	f += -1.0
	if length(g) > 0
		for i = 1:n
			g[i] = 1.0
		end
	end

	return f
end

xstart = zeros(n)
xstart[1] = 1.0

########### DIPIGRI #######################
opt = Opt(:LD_SLSQP, n)
xtol_rel!(opt,1e-4)

min_objective!(opt, quad!)
inequality_constraint!(opt, rend!, 1e-4)
equality_constraint!(opt, simpl!, 1e-4)
lower_bounds!(opt,zeros(n))
upper_bounds!(opt,ones(n))

(minf,minx,ret) = optimize(opt, xstart)
println("Optimization performed by ",algorithm_name(opt))
println("             Return code is: ",ret)
println("Best obj. function value is: ",minf)
println()

nothing
